#ifndef __JOINTCHAIN__
#define  __JOINTCHAIN__
/* Joint chain estimator
Peter Beerli January 2000
 
Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
Copyright 2003-2004 Peter Beerli, Tallahassee FL
 
$Id: joint-chains.h 1640 2010-02-06 16:28:21Z beerli $
    ----------------------------*/
void interpolate_like (nr_fmt * nr, long locus);
#endif
